Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1143)

Unified Diff: chrome/browser/extensions/external_provider_impl.h

Issue 10692168: Moved ExternalExtensionLoaders/Providers into extensions namespace (Closed) Base URL: http://git.chromium.org/chromium/src.git@master
Patch Set: Even later master Created 8 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/extensions/external_provider_impl.h
diff --git a/chrome/browser/extensions/external_extension_provider_impl.h b/chrome/browser/extensions/external_provider_impl.h
similarity index 65%
rename from chrome/browser/extensions/external_extension_provider_impl.h
rename to chrome/browser/extensions/external_provider_impl.h
index 0a5246b9d768c65cb5752219b195a8e271022c46..26384403c87e2e1901f949ab14549ac18eaf163c 100644
--- a/chrome/browser/extensions/external_extension_provider_impl.h
+++ b/chrome/browser/extensions/external_provider_impl.h
@@ -2,17 +2,16 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CHROME_BROWSER_EXTENSIONS_EXTERNAL_EXTENSION_PROVIDER_IMPL_H_
-#define CHROME_BROWSER_EXTENSIONS_EXTERNAL_EXTENSION_PROVIDER_IMPL_H_
+#ifndef CHROME_BROWSER_EXTENSIONS_EXTERNAL_PROVIDER_IMPL_H_
+#define CHROME_BROWSER_EXTENSIONS_EXTERNAL_PROVIDER_IMPL_H_
#include <string>
-#include "chrome/browser/extensions/external_extension_provider_interface.h"
+#include "chrome/browser/extensions/external_provider_interface.h"
#include "base/memory/ref_counted.h"
-#include "chrome/browser/extensions/external_extension_loader.h"
+#include "chrome/browser/extensions/external_loader.h"
-class ExternalExtensionLoader;
class Profile;
class Version;
@@ -22,14 +21,13 @@ class DictionaryValue;
namespace extensions {
class Extension;
-}
+class ExternalLoader;
-// A specialization of the ExternalExtensionProvider that uses an instance
-// of ExternalExtensionLoader to provide external extensions. This class
-// can be seen as a bridge between the extension system and an
-// ExternalExtensionLoader. Instances live their entire life on the UI thread.
-class ExternalExtensionProviderImpl
- : public ExternalExtensionProviderInterface {
+// A specialization of the ExternalProvider that uses an instance of
+// ExternalLoader to provide external extensions. This class can be seen as a
+// bridge between the extension system and an ExternalLoader. Instances live
+// their entire life on the UI thread.
+class ExternalProviderImpl : public ExternalProviderInterface {
public:
// The constructed provider will provide the extensions loaded from |loader|
// to |service|, that will deal with the installation. The location
@@ -38,14 +36,13 @@ class ExternalExtensionProviderImpl
// |download_location|: extensions originating from update URLs
// If either of the origins is not supported by this provider, then it should
// be initialized as Extensions::INVALID.
- ExternalExtensionProviderImpl(
- VisitorInterface* service,
- ExternalExtensionLoader* loader,
- extensions::Extension::Location crx_location,
- extensions::Extension::Location download_location,
- int creation_flags);
+ ExternalProviderImpl(VisitorInterface* service,
+ ExternalLoader* loader,
+ Extension::Location crx_location,
+ Extension::Location download_location,
+ int creation_flags);
- virtual ~ExternalExtensionProviderImpl();
+ virtual ~ExternalProviderImpl();
// Populates a list with providers for all known sources.
static void CreateExternalProviders(
@@ -54,15 +51,15 @@ class ExternalExtensionProviderImpl
ProviderCollection* provider_list);
// Sets underlying prefs and notifies provider. Only to be called by the
// owned ExternalExtensionLoader instance.
void SetPrefs(base::DictionaryValue* prefs);
- // ExternalExtensionProvider implementation:
+ // ExternalProvider implementation:
virtual void ServiceShutdown() OVERRIDE;
virtual void VisitRegisteredExtension() OVERRIDE;
virtual bool HasExtension(const std::string& id) const OVERRIDE;
virtual bool GetExtensionDetails(const std::string& id,
- extensions::Extension::Location* location,
+ Extension::Location* location,
scoped_ptr<Version>* version) const OVERRIDE;
virtual bool IsReady() const OVERRIDE;
@@ -80,11 +77,11 @@ class ExternalExtensionProviderImpl
private:
// Location for external extensions that are provided by this provider from
// local crx files.
- const extensions::Extension::Location crx_location_;
+ const Extension::Location crx_location_;
// Location for external extensions that are provided by this provider from
// update URLs.
- const extensions::Extension::Location download_location_;
+ const Extension::Location download_location_;
// Weak pointer to the object that consumes the external extensions.
// This is zeroed out by: ServiceShutdown()
@@ -99,7 +96,7 @@ class ExternalExtensionProviderImpl
// The loader that loads the list of external extensions and reports them
// via |SetPrefs|.
- scoped_refptr<ExternalExtensionLoader> loader_;
+ scoped_refptr<ExternalLoader> loader_;
// Creation flags to use for the extension. These flags will be used
// when calling Extenion::Create() by the crx installer.
@@ -109,7 +106,9 @@ class ExternalExtensionProviderImpl
// the user doesn't see an alert about them.
bool auto_acknowledge_;
- DISALLOW_COPY_AND_ASSIGN(ExternalExtensionProviderImpl);
+ DISALLOW_COPY_AND_ASSIGN(ExternalProviderImpl);
};
-#endif // CHROME_BROWSER_EXTENSIONS_EXTERNAL_EXTENSION_PROVIDER_IMPL_H_
+} // namespace extensions
+
+#endif // CHROME_BROWSER_EXTENSIONS_EXTERNAL_PROVIDER_IMPL_H_
« no previous file with comments | « chrome/browser/extensions/external_pref_loader.cc ('k') | chrome/browser/extensions/external_provider_impl.cc » ('j') | no next file with comments »

Powered by Google App Engine
@@ -54,15 +51,15 @@ class ExternalExtensionProviderImpl
ProviderCollection* provider_list);
// Sets underlying prefs and notifies provider. Only to be called by the
- // owned ExternalExtensionLoader instance.
+ // owned ExternalLoader instance.
void SetPrefs(base::DictionaryValue* prefs);
This is Rietveld 408576698